@@ -23,6 +23,7 @@ def lnprob(params, comps=None, dbf=None, phases=None, datasets=None,
            symbols_to_fit=None, phase_models=None, scheduler=None,
            massfuncs=None, massgradfuncs=None,
            callables=None, grad_callables=None, hess_callables=None,
+           thermochemical_callables=None,
            ):
     """
     Returns the error from multiphase fitting as a log probability.
@@ -39,7 +40,7 @@ def lnprob(params, comps=None, dbf=None, phases=None, datasets=None,
         multi_phase_error = [np.inf]
     multi_phase_error = [np.inf if np.isnan(x) else x ** 2 for x in multi_phase_error]
     multi_phase_error = -np.sum(multi_phase_error)
-    single_phase_error = calculate_thermochemical_error(dbf, comps, phases, datasets, parameters, phase_models=phase_models, callables=callables, massfuncs=massfuncs)
+    single_phase_error = calculate_thermochemical_error(dbf, comps, phases, datasets, parameters, phase_models=phase_models, callables=thermochemical_callables)
     actvity_error = calculate_activity_error(dbf, comps, phases, datasets, parameters=parameters, phase_models=phase_models, callables=callables, grad_callables=grad_callables, hess_callables=hess_callables, massfuncs=massfuncs, massgradfuncs=massgradfuncs)
     total_error = multi_phase_error + single_phase_error + actvity_error
     logging.debug('Single phase error: {:0.2f}. Multi phase error: {:0.2f}. Activity Error: {:0.2f}. Total error: {:0.2f}'.format(single_phase_error, multi_phase_error, actvity_error, total_error))
@@ -147,12 +148,30 @@ def mcmc_fit(dbf, datasets, mcmc_steps=1000, save_interval=100, chains_per_param
     eq_callables = eq_callables_dict(dbf, comps, phases, model=Model, param_symbols=sorted([sympy.Symbol(sym) for sym in symbols_to_fit], key=str))
     # because error_context expencts 'phase_models' key, change it
     eq_callables['phase_models'] = eq_callables.pop('model')
+    # we also need to build models that have no ideal mixing for thermochemical error and to build them for each property we might calculate
+    # TODO: potential optimization to only calculate for phase/property combos that we have in the datasets
+    # first construct dict of models without ideal mixing
+    mods_no_idmix = {}
+    for phase_name in phases:
+        mods_no_idmix[phase_name] = Model(dbf, comps, phase_name)
+        mods_no_idmix[phase_name].models['idmix'] = 0
+    # now construct callables for each possible property that can be calculated
+    thermochemical_callables = {}  # will be dict of {output_property: eq_callables_dict}
+    whitelist_properties = ['HM', 'SM', 'CPM']
+    whitelist_properties = whitelist_properties + [prop+'_MIX' for prop in whitelist_properties]
+    for prop in whitelist_properties:
+        thermochemical_callables[prop] = eq_callables_dict(dbf, comps, phases, model=mods_no_idmix, output=prop, param_symbols=sorted([sympy.Symbol(sym) for sym in symbols_to_fit], key=str), build_gradients=False)
+        # pop off the callables not used in properties because we don't want them around (they should be None, anyways)
+        thermochemical_callables[prop].pop('grad_callables')
+        thermochemical_callables[prop].pop('hess_callables')
+        thermochemical_callables[prop].pop('massgradfuncs')
     logging.debug('Finished building phase models')
 
     # context for the log probability function
     error_context = {'comps': comps, 'dbf': dbf,
                      'phases': phases, 'phase_models': eq_callables['phase_models'],
                      'datasets': datasets, 'symbols_to_fit': symbols_to_fit,
+                     'thermochemical_callables': thermochemical_callables,
                      }
 
     error_context.update(**eq_callables)
